import type { RpcAccount } from './Account';
import type { Context } from './Context';
import { PublicKey } from './PublicKey';
import type { RpcDataFilter, RpcDataSlice, RpcGetProgramAccountsOptions } from './RpcInterface';
import { StructToSerializerTuple } from './SerializerInterface';
export type GpaBuilderSortCallback = (a: RpcAccount, b: RpcAccount) => number;
export declare class GpaBuilder<T extends object = {}> {
    protected readonly context: Pick<Context, 'rpc'>;
    readonly programId: PublicKey;
    readonly fields?: StructToSerializerTuple<T, T> | undefined;
    readonly options: {
        sortCallback?: GpaBuilderSortCallback;
        dataSlice?: RpcDataSlice;
        filters?: RpcDataFilter[];
    };
    constructor(context: Pick<Context, 'rpc'>, programId: PublicKey, fields?: StructToSerializerTuple<T, T> | undefined, options?: {
        sortCallback?: GpaBuilderSortCallback;
        dataSlice?: RpcDataSlice;
        filters?: RpcDataFilter[];
    });
    reset(): GpaBuilder<T>;
    slice(offset: number, length: number): GpaBuilder<T>;
    withoutData(): GpaBuilder<T>;
    addFilter(...filters: RpcDataFilter[]): GpaBuilder<T>;
    where(offset: number, data: string | bigint | number | boolean | Uint8Array | PublicKey): GpaBuilder<T>;
    whereField<K extends keyof T>(field: K, data: T[K]): GpaBuilder<T>;
    whereSize(dataSize: number): GpaBuilder<T>;
    sortUsing(callback: GpaBuilderSortCallback): GpaBuilder<T>;
    get(options?: RpcGetProgramAccountsOptions): Promise<RpcAccount[]>;
    getAndMap<U>(callback: (account: RpcAccount) => U, options?: RpcGetProgramAccountsOptions): Promise<U[]>;
    getPublicKeys(options?: RpcGetProgramAccountsOptions): Promise<PublicKey[]>;
    getDataAsPublicKeys(options?: RpcGetProgramAccountsOptions): Promise<PublicKey[]>;
}
export declare const gpaBuilder: <T extends object = {}>(context: Pick<Context, 'rpc'>, programId: PublicKey, fields?: StructToSerializerTuple<T, T> | undefined) => GpaBuilder<T>;
